VectorSpace

Trait VectorSpace 

pub trait VectorSpace: TwoSidedModule
where <Self as TwoSidedModule>::Ring: Field,
{ }
A trait representing a vector space over a field.

A vector space is a module over a field, meaning it has both addition and scalar multiplication operations, with the scalars coming from a field.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl VectorSpace for Boolean

Source

impl<F: Field + Mul<Self>, const N: usize, Q: QuadraticFormMarker<F, N>> VectorSpace for CliffordAlgebraElement<F, N, Q>
where [(); { _ }]:,